@@ -1,6 +1,6 @@
 #!/bin/sh
 #
-# Copyright (C) 2004, 2007, 2012, 2013  Internet Systems Consortium, Inc. ("ISC")
+# Copyright (C) 2004, 2007, 2012, 2013, 2015  Internet Systems Consortium, Inc. ("ISC")
 # Copyright (C) 2000, 2001, 2003  Internet Software Consortium.
 #
 # Permission to use, copy, modify, and/or distribute this software for any
@@ -40,6 +40,7 @@ Libraries:
 	dns
 	lwres
 	bind9
+	irs
 EOF
 	exit $1
 }
@@ -73,7 +74,7 @@ while test $# -gt 0; do
 		echo_exec_prefix=true
 		;;
 	--version)
-		echo VERSION=9.10.1-P2
+		echo VERSION=9.10.4-P2
 		exit 0
 		;;
 	--cflags)
@@ -82,7 +83,13 @@ while test $# -gt 0; do
 	--libs)
 		echo_libs=true;
 		;;
-	isc)
+	irs)
+		libirs=true;
+		libdns=true;
+		libisccfg=true;
+		libisc=true;
+		;;
+	isc) 
 		libisc=true;
 		;;
 	isccc)
@@ -125,16 +132,19 @@ if test x"$echo_cflags" = x"true"; then
 		includes="-I${includedir}"
 	fi
 	if test x"$libisc" = x"true"; then
-		includes="$includes -D_REENTRANT    -pthread"
+		includes="$includes -D_REENTRANT  -DDIG_SIGCHASE=1  -pthread"
 	fi
 	echo $includes
 fi
 if test x"$echo_libs" = x"true"; then
 	if test x"${exec_prefix_set}" = x"true"; then
-		includes="-L${exec_prefix}/lib"
+		libs="-L${exec_prefix}/lib"
 	else
 		libs="-L${libdir}"
 	fi
+	if test x"$libirs" = x"true" ; then
+		libs="$libs -lirs"
+	fi
 	if test x"$liblwres" = x"true" ; then
 		libs="$libs -llwres"
 	fi
@@ -155,7 +165,7 @@ if test x"$echo_libs" = x"true"; then
 		needothers=true
 	fi
 	if test x"$needothers" = x"true" ; then
-		libs="$libs  -pthread -lpthread -lm -lGeoIP  -L/usr/local/lib -Wl,-rpath=/usr/local/lib -L/usr/local/lib -lxml2 -lz -L/usr/local/lib -liconv -lm"
+		libs="$libs  -pthread -ljson-c -lpthread -lm -lGeoIP  -L/usr/local/lib -Wl,-rpath=/usr/local/lib -L/usr/local/lib -lxml2 -lz -L/usr/local/lib -liconv -lm -L/usr/local/lib"
 	fi
 	echo $libs
 fi
